function [clusters, probcnts] = fpmcreate(seq, symbols, clstcnt, dummysteps, km_alpha, km_maxepochs, km_msetostop);

% check existance of input sequence
if nargin < 2,
    error('Missing input argument.');    
end;

% transform input sequence into symbol indeces seq.
[ind_seq, sym_cnt] = seq2ind(seq, symbols);
len = length(ind_seq);

% set number of clusters
if nargin < 3,
    clstcnt = 10;
    fprintf('Using %d clusters.\n', clstcnt);    
end;

% check validity of requested cluster count
% more clusters then input vectors is allowed
if clstcnt < 1,
    error('Requested number of clusters should be > 0.');    
end;

% set number of dummy steps
if nargin < 4,
    dummysteps = 100;
    fprintf('Number of dummy steps is %d.\n', dummysteps);    
end;

% check validity of dummysteps
if dummysteps >= len+1,
    error('Number of dummy steps is higher then sequence length.');    
end;

% create fpm activities and clusters
act = fpmact(seq, sym_cnt);

% removing dummy steps and moving sequence one step back 
act(:,1:dummysteps) = [];
act(:,end) = [];
ind_seq(:,1:dummysteps+1) = [];
len = length(ind_seq);

% perform kmeans clustering
if nargin < 5, km_alpha = 0.05;     fprintf('K-means learning rate is set to %f.\n', km_alpha); end;
if nargin < 6, km_maxepochs = 20;   fprintf('K-means maximal epoch count set to %d.\n', km_maxepochs); end;
if nargin < 7, km_msetostop = 0;    fprintf('K-means minimal clusters'' displacement %f.\n', km_msetostop); end;

[clusters, clstusg] = kmeans(act, clstcnt, km_alpha, km_maxepochs, km_msetostop);

% check clusters for usefullness
unused = find(clstusg == 0);
if ~isempty(unused),
    fprintf('Number of unused clustres is %d.\n', length(unused));
    fprintf('Cluster no. %d is unused.\n', unused);
end;

% create zero matrix of cluster prediction counters
probcnts = zeros(sym_cnt, clstcnt);

% compute cluster prediction counters
for i=(1:len),
    win = find_winner_index_rnd(act(:,i), clusters);
    probcnts(ind_seq(i), win) = probcnts(ind_seq(i), win)+1;
end;
