function [mse, nnl] = fpmtest(seq, symbols, clusters, probcnts, dummysteps, lplcorr);

% check existance of input arguments
if nargin < 4,
    error('Missing input arguments.');    
end;

% transform input sequence into symbol indeces seq.
[ind_seq, sym_cnt] = seq2ind(seq, symbols);
len = length(ind_seq);
clstcnt = size(clusters, 2);

if sym_cnt ~= size(probcnts, 1),
    error('Number of symbols of the input sequence and dimension of the probability counters do not match.');
end;    
    
% set number of dummy steps
if nargin < 5,
    dummysteps = 100;
    fprintf('Number of dummy steps is %d.\n', dummysteps);    
end;

% check validity of dummysteps
if dummysteps >= len+1,
    error('Number of dummy steps is higher then sequence length.');    
end;

% set min. prob. value
if nargin < 6,
    lplcorr = 1/sym_cnt;
    fprintf('Laplace correction parameter was set to %f.\n', lplcorr);    
end;

% create fpm activities and clusters
act = fpmact(seq, sym_cnt);
if size(act, 1) ~= size(clusters, 1),
    error('Dimension of the activities based on the input sequence and cluster dimension do not match.');
end;

% removing dummy steps and moving sequence one step back 
act(:,1:dummysteps) = [];
act(:,end) = [];
ind_seq(:,1:dummysteps+1) = [];
len = length(ind_seq);

% deal with near zero prob. - smooth distribution with using Laplace Correction 
if lplcorr <= 0, 
    lplcorr = 1/sym_cnt; 
end;
probcnts = probcnts + lplcorr;
probsums = repmat(sum(probcnts), sym_cnt, 1);
prob = probcnts ./ probsums;
    
% create probabilities sequence
prob_seq = zeros(size(ind_seq));
for i=(1:len),
    win = find_winner_index_rnd(act(:,i), clusters);
    prob_seq(i) = prob(ind_seq(i), win);
end;

% calculate MSE and NNL
mse = sum((1-prob_seq).^2) / len;
nnl = -sum(log(prob_seq)) / len / log(sym_cnt);



