function fpm = create_fpm(seq, clstcnt);
% CREATE_FPM - K-means clustering
% inp act    - input vectors
% clstusg    - cluster usage

% check existance of input sequence
if nargin < 1,
    error('Missing input argument.');    
end;

% set number of clusters
if nargin < 2,
    clstcnt = 10;
    fprintf('Using %d clusters.\n', clstcnt);    
end;

% check validity of requested cluster count
% more clusters then input vectors is allowed
if clstcnt < 1,
    error('Requested number of clusters should be > 0 ');    
end;

act = fpmact(seq, dim);
[fpm.clusters, clstusg] = kmeans(act, clstcnt);

unused = find(clstusg == 0);
if ~empty(unused),
    printf('Unused clustres are %d', unused);
end;

fpm.probs =  fpm.clusters, seq);



% transform input sequience into one-hot-encodeing seq.
ind_seq = seq2ind(seq);








% check dimensions 
len = size(inp_act,2);
if ndims(inp_act)~=2 | isempty(inp_act) | size(inp_act,2) < 2,
    error('Bad dimensions of input matrix');  
end;       

% 
fpm.centers = kmeans




% initialize clusters
clst_ind = ceil(rand(1, clstcnt)*len);
clusters = inp_act(:,clst_ind);

% preparation 
max_step = 100;
alpha = 0.1;
min_nmse_change = 0.00001;
nind = zeros(1,clstcnt);

% start EM epochs
for step=(1:max_step),
    fprintf('EM-epoch %d\n', step);
    
    old_clusters = clusters;
    
    % EM step
    for i=(1:len),
        % Expectation step
        nind(:) = i;
        rep_int_act = inp_act(:,nind);
        win = find_nearest_ind_rnd(rep_int_act, clusters);
       
        % Maximization step
        clusters(:,win) = clusters(:,win) + (inp_act(:,i) - clusters(:,win)) * alpha;
    end;
        
    % Get step change
    diff_nmse = sum((old_clusters - clusters).^2) / prod(size(clusters));
    if diff_nmse < min_nmse_change,
        break;
    end;        
end;

% cluster statistics
nmse = 0;
clstusg = zeros(1, clstcnt);
for i=(1:len),
    win = find_winner_index(inp_act(:,i), clusters);
    nmse = nmse + sum((inp_act(:,i) - clusters(:,win)).^2);   
    clstusg(win) = clstusg(win)+1;
end;

nmse = nmse / (len * size(clusters,1));
fprintf('Process finished after %d epochs with NMSE=%f', step,nmse);


function win_ind = find_nearest_ind_rnd(vectors1, vectors2);
% function finds index of the cluster the nearest to the input vector
diffs = (vectors1-vectors2).^2;
if size(diffs,1) > 1, diffs = sum(diffs); end;
wins = find(diffs == min(diffs));
win_ind = wins(ceil(rand * length(wins)));


function win_ind = find_winner_index_rnd(vector, clusters);
% function finds index of the cluster the nearest to the input vector
diffs = (repmat(vector, 1, size(clusters,2)) - clusters).^2;
if size(diffs,1) > 1, diffs = sum(diffs); end;
wins = find(diffs == min(diffs));
win_ind = wins(ceil(rand * length(wins)));


function win_ind = find_winner_index(vector, clusters);
% function finds index of the cluster the nearest to the input vector
diffs = (repmat(vector, 1, size(clusters,2)) - clusters).^2;
if size(diffs,1) > 1, diffs = sum(diffs); end;
wins = find(diffs == min(diffs));
win_ind = wins(1);




