function out_act = fpmact(seq, dim)
% FPMACT - creates fpm activities from input sequence
%
% out_act = FPMACT(seq);
% seq       - input sequence (character array, symbol indeces or
%             one-hot-encoded input
% dim       - size of input alphabet, if omitted or less then 2, set
%             according to input sequence
% out_act   - output activations

% transform input sequience into one-hot-encodeing seq.
ind_seq = seq2ind(seq);

% get dimension and length of sequence
len = length(ind_seq);
if nargin<2 | dim < 2,
    dim = max(ind_seq);
end;

if dim < max(ind_seq),
    error('Input sequence dimension (%d) is higher then given dimension (%d)', max(ind_seq), dim);
end;
    
% create transformation matrices x(t+1) = RW(i) * [x(t), 1]' where index
% i specifies transfomation, 
% 1st index - row - new transformation vector index
% 2nd index - col - previous transformation vector index
% 3rd index -     - input transformation index (according to input symbol)
RW = zeros(dim, dim+1, dim);
for i=(1:dim)
    RW(i,i,:) = 0.5;          
    RW(i,end,i) = 0.5;
end;


% create output activations, starting act, is the middle of state space
% (0,1)^dim
out_act = zeros(dim, len+1);
out_act(:,1) = 0.5;
for i=(2:len+1)
    out_act(:,i) = RW(:,:,ind_seq(i-1)) * [out_act(:,i-1); 1];
end;

% remove starting activations
out_act(:,1) = [];