function [clusters, clstusg] = kmeans(inp_act, clstcnt, alpha, max_step, min_nmse_change);
% KMEANS   - K-means clustering

% check existance of input sequence
if nargin < 1,
    error('Missing input argument.');    
end;

% set number of clusters
if nargin < 2,
    clstcnt = 10;
    fprintf('Using %d clusters.\n', clstcnt);    
end;

% check validity of requested cluster count
% more clusters then input vectors is allowed
if clstcnt < 1,
    error('Requested number of clusters should be > 0 ');    
end;

% set EM learning rate
if nargin < 3,
    alpha = 0.05;
    fprintf('EM learning rate was set to %f\n', alpha);
end;

% set maximal epochs count stop condition
if nargin < 4,
    max_step = 20;
    fprintf('Maximal epoch count set to %d.\n', max_step);
end;

% set minimal nmse change stop condition
if nargin < 5,
    min_nmse_change = 1.0e-10;
    fprintf('Minimal NMSE change set to %f.\n', min_nmse_change);
end;

% check dimensions 
len = size(inp_act,2);
if ndims(inp_act)~=2 | isempty(inp_act) | size(inp_act,2) < 2,
    error('Bad dimensions of input matrix');  
end;       

% initialize clusters
clst_ind = ceil(rand(1, clstcnt)*len);
clusters = inp_act(:,clst_ind);

% start EM epochs
for step=(1:max_step),
    fprintf('EM-epoch %d\n', step);
    
    old_clusters = clusters;
    
    % EM step
    for i=(1:len),
        % Expectation step
        win = find_winner_index_rnd(inp_act(:,i), clusters);

        % Maximization step
        clusters(:,win) = clusters(:,win) + (inp_act(:,i) - clusters(:,win)) * alpha;
    end;
        
    % Get step change
    diff_nmse = sum((old_clusters - clusters).^2) / prod(size(clusters));
    if diff_nmse < min_nmse_change,
        break;
    end;        
end;

% cluster statistics
nmse = 0;
clstusg = zeros(1, clstcnt);
for i=(1:len),
    win = find_winner_index(inp_act(:,i), clusters);
    nmse = nmse + sum((inp_act(:,i) - clusters(:,win)).^2);   
    clstusg(win) = clstusg(win)+1;
end;

nmse = nmse / (len * size(clusters,1));
fprintf('Process finished after %d epochs with NMSE=%f\n', step,nmse);
