function [ind_seq, sym_cnt] = seq2ind(seq, symbols)
% SEQ2IND - transform character array or one-hot-encoded activities into
% sequence of symbol indeces
%
% [ind_seq, sym_cnt] = SEQ2IND(seq, symbols)
% seq       - character array or one-hot-encoded activities
% symbols   - symbol aplhabet of the character array input sequence seq
% ind_seq   - indeces of input alphabet
% sym_cnt   - number of (theoretically possible) symbols

% check existance of input sequence
if nargin < 1,
    error('Missing input argument.');    
end;

% check existance of symbols used in the character array input sequence
if nargin < 2,
    symbols = '';
end;

% check input sequence size
[dim, len] = size(seq);
if len < 1,
    error('Zero-length input sequence.');
end;

% transform one-hot-encoded input sequence into indeces
if isoheseq(seq),
    ind_seq = (mod(find(seq == 1) - 1, dim) + 1)';
    return;
end;

% except one-hot-encoded input, dimension must be 1
if dim ~= 1,
    error('Wrong input argument. Must be one-hot-encoded input sequence or character array.');
end;

% transform character arry into indeces
if ischar(seq),
    if(isempty(symbols))
        [p, i, ind_seq] = unique(seq);
        sym_cnt = max(ind_seq);
    else
        if length(symbols) ~= length(unique(symbols)),
            error('Alphabet symbols must be unique');
        end;
        
        extra_symbols = setdiff(seq, symbols);
        if ~isempty(extra_symbols),
            fprintf('Symbol %c not found in alphabet symbols\n', extra_symbols);
            error('Some symbol(s) not found in the alphabet.');
        end;
        
        [p, i, ind_seq] = unique([symbols,seq]);
        sym_cnt = length(symbols);
        ind_seq(1:sym_cnt) = [];
    end;
        
    return;
end;

% if already indeces, keep seq
if isindseq(seq),
    ind_seq = seq;
    return;
end;

% wrong argument 
error('Wrong input argument. Must be one-hot-encoded input sequence or character array.');
