function ohe_act = seq2ohe(seq)
% SEQ2OHE - transform character array or seq of transformation indeces into
% sequence of one-hot-encoded activities
%
% ohe_seq = SEQ2OHE(seq)
% seq       - character array or indeces of input alphabet
% ohe_act   - one-hot-encoded activities


% check input sequence size
[dim, len] = size(seq);
if len < 1,
    error('Zero-length input sequence.');
end;

% if input sequence is one-hot-encoded, keep it
if isohe(seq),
    ohe_act = seq;
end;
    
% check input dimension, must be 1
if dim ~= 1,
    error('Wrong input sequence dimension.');
end;

% transform character arry into indeces
if ischar(seq),
    [p, i, i_seq] = unique(seq);
else
    i_seq = seq;
end;

% create one-hot-encoded codes
codes = eye(max(i_seq));
ohe_act = codes(:,i_seq);



